neuromorpho_ext

Macro neuromorpho_ext 

macro_rules! neuromorpho_ext {
    ( $id:ident $(, $val:literal = $name:ident $desc:expr )* $(,)?) => { ... };
    ( $id:ident $(, $val:literal = $name:ident $desc:expr )*, $othername:ident $(,)?) => { ... };
}
Thin wrapper around the structure_mapping macro for producing enums which extend the Neuromorpho SWC standard (i.e. have additional structure types in the Custom block, 5+).

Again, you can either allow or disallow the catch-all case.