Module structures

Module structures 

Module for types represented by the structure ID field of a SWC sample.

Contains some known structure schemas and macros for creating more.

Enums

AnyStructure
CnicStructure
GulyasStructure
NavisStructure
NeuromorphoStructure
VnedStructure

Traits

StructureIdentifier
Trait for the structures represented by samples, identified by an integer.