Module header
swc_
neuron
0.5.3
Module header
Module Items
Traits
In crate swc_
neuron
swc_neuron
Module
header
Module for metadata contained in the header of the SWC file.
Traits

Header
Trait for metadata which can be read and written from a block comment at the head of the file.