Module swc_neuron::header

source ·
Module for metadata contained in the header of the SWC file.

Traits

  • Trait for metadata which can be read and written from a block comment at the head of the file.