pub trait Header:
Clone
+ Debug
+ ToString
+ FromStr { }Expand description
Trait for metadata which can be read and written from a block comment at the head of the file.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.