Trait swc_neuron::header::Header
source · pub trait Header: Clone + Debug + ToString + FromStr { }Expand description
Trait for metadata which can be read and written from a block comment at the head of the file.
Object Safety
This trait is not object safe.