Module swc_neuron::structures
source · Expand description
Module for types represented by the structure ID field of a SWC sample.
Contains some known structure schemas and macros for creating more.
Enums
Traits
- Trait for the structures represented by samples, identified by an integer.